@@ -1,6 +1,6 @@
 # mypy: allow-untyped-defs
 
-# generate generates a new recipe scraper.
+# generate.py generates a new recipe scraper.
 import ast
 import json
 import os
@@ -35,20 +35,20 @@ def generate_scraper_test(class_name, host_name):
         os.mkdir(f"tests/test_data/{host_name}")
 
     testjson = {
-        "author": "",
-        "canonical_url": "",
         "host": host_name,
-        "description": "",
-        "image": "",
+        "canonical_url": "",
+        "site_name": "",
+        "author": "",
+        "language": "",
+        "title": "",
         "ingredients": "",
         "ingredient_groups": "",
         "instructions": "",
         "instructions_list": "",
-        "language": "",
-        "site_name": "",
-        "title": "",
         "total_time": "",
         "yields": "",
+        "image": "",
+        "description": "",
     }
 
     output = f"tests/test_data/{host_name}/{class_name.lower()}.json"
@@ -73,8 +73,8 @@ def init_scraper(class_name):
 
 def generate_test_data(class_name, host_name, content):
     output = f"tests/test_data/{host_name}/{class_name.lower()}.testhtml"
-    with open(output, "wb") as target:
-        target.write(content)
+    with open(output, "w", encoding="utf-8") as target:
+        target.write(content.decode(encoding="utf-8"))
 
 
 class ScraperState:
