@@ -15,20 +15,11 @@ class CookTalk(AbstractScraper):
         )
         return author_element.get_text()
 
-    def title(self):
-        return self.schema.title()
-
     def category(self):
         article_meta = self.soup.find("div", {"class": "article-meta"})
         category_element = article_meta.find("small", {"class": "meta-category"})
         return category_element.find("a").get_text()
 
-    def image(self):
-        return self.schema.image()
-
-    def ingredients(self):
-        return self.schema.ingredients()
-
     def ingredient_groups(self):
         return group_ingredients(
             self.ingredients(),
@@ -36,9 +27,3 @@ class CookTalk(AbstractScraper):
             "div.ingredient-label",
             "ul#zlrecipe-ingredients-list li.ingredient",
         )
-
-    def instructions(self):
-        return self.schema.instructions()
-
-    def description(self):
-        return self.schema.description()
