@@ -8,9 +8,6 @@ class DomesticateMe(AbstractScraper):
     def host(cls):
         return "domesticate-me.com"
 
-    def title(self):
-        return self.schema.title()
-
     def author(self):
         author_from_schema = self.schema.author()
         if author_from_schema:
@@ -20,24 +17,6 @@ class DomesticateMe(AbstractScraper):
         author_name = author_meta_tag["content"] if author_meta_tag else None
         return author_name
 
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def image(self):
-        return self.schema.image()
-
-    def ingredients(self):
-        return self.schema.ingredients()
-
-    def instructions(self):
-        return self.schema.instructions()
-
-    def ratings(self):
-        return self.schema.ratings()
-
     def ingredient_groups(self):
         return group_ingredients(
             self.ingredients(),
