@@ -9,9 +9,6 @@ class IG(AbstractScraper):
     def host(cls):
         return "receitas.ig.com.br"
 
-    def title(self):
-        return self.schema.title()
-
     def author(self):
         nav = self.soup.find("nav", {"class": "nav-mais-receitas"})
         if nav:
@@ -19,9 +16,6 @@ class IG(AbstractScraper):
             if first:
                 return first.find("a").get_text()
 
-    def total_time(self):
-        return self.schema.total_time()
-
     def yields(self):
         container = self.soup.find("div", {"class": "box-info-rendimento"})
         if not container:
@@ -29,12 +23,6 @@ class IG(AbstractScraper):
         else:
             return get_yields(container.find("span", {"class": "valor"}).get_text())
 
-    def image(self):
-        return self.schema.image()
-
-    def ingredients(self):
-        return self.schema.ingredients()
-
     def instructions(self):
         instructions = self.soup.find("div", {"class": "box-preparo"})
         return normalize_string(instructions.get_text())
