@@ -8,18 +8,6 @@ class KennyMcGovern(AbstractScraper):
     def host(cls):
         return "kennymcgovern.com"
 
-    def title(self):
-        return self.schema.title()
-
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def ingredients(self):
-        return self.schema.ingredients()
-
     def instructions(self):
         instructions = self.soup.findAll(
             "div", {"class": "wprm-recipe-instruction-text"}
