@@ -9,21 +9,6 @@ class Matprat(AbstractScraper):
     def host(cls):
         return "matprat.no"
 
-    def title(self):
-        return self.schema.title()
-
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def image(self):
-        return self.schema.image()
-
-    def ingredients(self):
-        return self.schema.ingredients()
-
     def ingredient_groups(self):
         return group_ingredients(
             self.ingredients(),
@@ -32,15 +17,6 @@ class Matprat(AbstractScraper):
             "ul.ingredientsList > li > span:not(.amount):not(.unit)",
         )
 
-    def instructions(self):
-        return self.schema.instructions()
-
-    def ratings(self):
-        return self.schema.ratings()
-
-    def description(self):
-        return self.schema.description()
-
     def nutrients(self):
         nutrient_names = [
             x.text for x in self.soup("td", "recipe-nutritions__table-cell-name")
