@@ -11,12 +11,6 @@ class SouthernLiving(AbstractScraper):
     def host(cls):
         return "southernliving.com"
 
-    def title(self):
-        return self.schema.title()
-
-    def total_time(self):
-        return self.schema.total_time()
-
     def yields(self):
         try:
             schema_yield = self.schema.yields()
@@ -36,15 +30,3 @@ class SouthernLiving(AbstractScraper):
                     "div", class_="mntl-recipe-details__value"
                 )
                 return get_yields(servings_element)
-
-    def image(self):
-        return self.schema.image()
-
-    def ingredients(self):
-        return self.schema.ingredients()
-
-    def instructions(self):
-        return self.schema.instructions()
-
-    def description(self):
-        return self.schema.description()
