@@ -8,18 +8,6 @@ class TheSpruceEats(AbstractScraper):
     def host(cls):
         return "thespruceeats.com"
 
-    def title(self):
-        return self.schema.title()
-
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def image(self):
-        return self.schema.image()
-
     def ingredients(self):
         ingredients = self.soup.select("li.structured-ingredients__list-item p")
         extracted_ingredients = []
@@ -35,6 +23,3 @@ class TheSpruceEats(AbstractScraper):
             "p.structured-ingredients__list-heading",
             "li.structured-ingredients__list-item p",
         )
-
-    def instructions(self):
-        return self.schema.instructions()
