@@ -10,24 +10,6 @@ class UitPaulinesKeukenNL(AbstractScraper):
     def host(cls):
         return "uitpaulineskeuken.nl"
 
-    def author(self):
-        return self.schema.author()
-
-    def title(self):
-        return self.schema.title()
-
-    def category(self):
-        return self.schema.category()
-
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def image(self):
-        return self.schema.image()
-
     def ingredients(self):
         ingredients = self.soup.find("section", {"id": "ingredienten"}).findChildren(
             "li"
@@ -50,14 +32,8 @@ class UitPaulinesKeukenNL(AbstractScraper):
             [normalize_string(instruction.get_text()) for instruction in instructions]
         )
 
-    def ratings(self):
-        return self.schema.ratings()
-
-    def cuisine(self):
-        return self.schema.cuisine()
-
     def description(self):
-        return (
+        return normalize_string(
             self.soup.find("article", {"class": "single-recipe"})
             .findChild("section", {"class": "text"})
             .find_next()
