@@ -9,21 +9,6 @@ class ZauberTopf(AbstractScraper):
     def host(cls):
         return "zaubertopf.de"
 
-    def author(self):
-        return self.schema.author()
-
-    def title(self):
-        return self.schema.title()
-
-    def category(self):
-        return self.schema.category()
-
-    def total_time(self):
-        return self.schema.total_time()
-
-    def image(self):
-        return self.schema.image()
-
     def ingredients(self):
         for h2_element in self.soup.find_all("h2"):
             if "Die Zutaten" in h2_element.text:
@@ -43,6 +28,3 @@ class ZauberTopf(AbstractScraper):
                     return "\n".join(
                         [li.get_text() for li in ol_element.find_all("li") if li.text]
                     )
-
-    def description(self):
-        return self.schema.description()
